@@ -35,7 +35,7 @@
     MMMd => "MMM d",
     Md => "M/d",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm\N{U+202f}a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -47,21 +47,21 @@
     yMMM => "MMM y",
     yMMMEd => "E, MMM d, y",
     yMMMM => "MMMM y",
-    yMMMd => "y MMM d",
+    yMMMd => "MMM d, y",
     yMd => "y/M/d",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
     "yw-count-other" => "'week' w 'of' Y",
   },
   code => "ak",
-  date_format_full => "EEEE, y MMMM dd",
-  date_format_long => "y MMMM d",
-  date_format_medium => "y MMM d",
-  date_format_short => "yy/MM/dd",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  date_format_full => "EEE, MMMM d, y",
+  date_format_long => "MMMM d, y",
+  date_format_medium => "MMM d, y",
+  date_format_short => "M/d/yy",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "Dwo",
     "Ben",
@@ -81,13 +81,13 @@
     "K",
   ],
   day_format_wide => [
-    "Dwowda",
+    "Dwoada",
     "Benada",
-    "Wukuda",
-    "Yawda",
-    "Fida",
+    "Wukuada",
+    "Yawoada",
+    "Fiada",
     "Memeneda",
-    "Kwesida",
+    "Kwasiada",
   ],
   day_stand_alone_abbreviated => [
     "Dwo",
@@ -108,13 +108,13 @@
     "K",
   ],
   day_stand_alone_wide => [
-    "Dwowda",
+    "Dwoada",
     "Benada",
-    "Wukuda",
-    "Yawda",
-    "Fida",
+    "Wukuada",
+    "Yawoada",
+    "Fiada",
     "Memeneda",
-    "Kwesida",
+    "Kwasiada",
   ],
   era_abbreviated => [
     "AK",
@@ -126,7 +126,7 @@
   ],
   era_wide => [
     "Ansa Kristo",
-    "Kristo Ekyiri",
+    "Kristo Akyi",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -136,88 +136,88 @@
   glibc_time_format => "%H:%M:%S",
   language => "Akan",
   month_format_abbreviated => [
-    "S-\N{U+0186}",
-    "K-\N{U+0186}",
-    "E-\N{U+0186}",
-    "E-O",
-    "E-K",
-    "O-A",
-    "A-K",
-    "D-\N{U+0186}",
-    "F-\N{U+0190}",
-    "\N{U+0186}-A",
-    "\N{U+0186}-O",
-    "M-\N{U+0186}",
+    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
+    "\N{U+0186}gyefo\N{U+0254}",
+    "\N{U+0186}b\N{U+025b}nem",
+    "Oforisuo",
+    "K\N{U+0254}t\N{U+0254}nimma",
+    "Ay\N{U+025b}wohomumu",
+    "Kutawonsa",
+    "\N{U+0186}sanaa",
+    "\N{U+0190}b\N{U+0254}",
+    "Ahinime",
+    "Obubuo",
+    "\N{U+0186}p\N{U+025b}nimma",
   ],
   month_format_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "\N{U+0186}",
+    "\N{U+0186}",
+    "\N{U+0186}",
+    "O",
+    "K",
+    "A",
+    "K",
+    "\N{U+0186}",
+    "\N{U+0190}",
+    "A",
+    "O",
+    "\N{U+0186}",
   ],
   month_format_wide => [
-    "Sanda-\N{U+0186}p\N{U+025b}p\N{U+0254}n",
-    "Kwakwar-\N{U+0186}gyefuo",
-    "Eb\N{U+0254}w-\N{U+0186}benem",
-    "Eb\N{U+0254}bira-Oforisuo",
-    "Esusow Aketseaba-K\N{U+0254}t\N{U+0254}nimba",
-    "Obirade-Ay\N{U+025b}wohomumu",
-    "Ay\N{U+025b}woho-Kitawonsa",
-    "Difuu-\N{U+0186}sandaa",
-    "Fankwa-\N{U+0190}b\N{U+0254}",
-    "\N{U+0186}b\N{U+025b}s\N{U+025b}-Ahinime",
-    "\N{U+0186}ber\N{U+025b}f\N{U+025b}w-Obubuo",
-    "Mumu-\N{U+0186}p\N{U+025b}nimba",
+    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
+    "\N{U+0186}gyefo\N{U+0254}",
+    "\N{U+0186}b\N{U+025b}nem",
+    "Oforisuo",
+    "K\N{U+0254}t\N{U+0254}nimma",
+    "Ay\N{U+025b}wohomumu",
+    "Kutawonsa",
+    "\N{U+0186}sanaa",
+    "\N{U+0190}b\N{U+0254}",
+    "Ahinime",
+    "Obubuo",
+    "\N{U+0186}p\N{U+025b}nimma",
   ],
   month_stand_alone_abbreviated => [
-    "S-\N{U+0186}",
-    "K-\N{U+0186}",
-    "E-\N{U+0186}",
-    "E-O",
-    "E-K",
-    "O-A",
-    "A-K",
-    "D-\N{U+0186}",
-    "F-\N{U+0190}",
-    "\N{U+0186}-A",
-    "\N{U+0186}-O",
-    "M-\N{U+0186}",
+    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
+    "\N{U+0186}gyefo\N{U+0254}",
+    "\N{U+0186}b\N{U+025b}nem",
+    "Oforisuo",
+    "K\N{U+0254}t\N{U+0254}nimma",
+    "Ay\N{U+025b}wohomumu",
+    "Kutawonsa",
+    "\N{U+0186}sanaa",
+    "\N{U+0190}b\N{U+0254}",
+    "Ahinime",
+    "Obubuo",
+    "\N{U+0186}p\N{U+025b}nimma",
   ],
   month_stand_alone_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "\N{U+0186}",
+    "\N{U+0186}",
+    "\N{U+0186}",
+    "O",
+    "K",
+    "A",
+    "K",
+    "\N{U+0186}",
+    "\N{U+0190}",
+    "A",
+    "O",
+    "\N{U+0186}",
   ],
   month_stand_alone_wide => [
-    "Sanda-\N{U+0186}p\N{U+025b}p\N{U+0254}n",
-    "Kwakwar-\N{U+0186}gyefuo",
-    "Eb\N{U+0254}w-\N{U+0186}benem",
-    "Eb\N{U+0254}bira-Oforisuo",
-    "Esusow Aketseaba-K\N{U+0254}t\N{U+0254}nimba",
-    "Obirade-Ay\N{U+025b}wohomumu",
-    "Ay\N{U+025b}woho-Kitawonsa",
-    "Difuu-\N{U+0186}sandaa",
-    "Fankwa-\N{U+0190}b\N{U+0254}",
-    "\N{U+0186}b\N{U+025b}s\N{U+025b}-Ahinime",
-    "\N{U+0186}ber\N{U+025b}f\N{U+025b}w-Obubuo",
-    "Mumu-\N{U+0186}p\N{U+025b}nimba",
+    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
+    "\N{U+0186}gyefo\N{U+0254}",
+    "\N{U+0186}b\N{U+025b}nem",
+    "Oforisuo",
+    "K\N{U+0254}t\N{U+0254}nimma",
+    "Ay\N{U+025b}wohomumu",
+    "Kutawonsa",
+    "\N{U+0186}sanaa",
+    "\N{U+0190}b\N{U+0254}",
+    "Ahinime",
+    "Obubuo",
+    "\N{U+0186}p\N{U+025b}nimma",
   ],
   name => "Akan",
   native_language => "Akan",
@@ -226,10 +226,10 @@
   native_territory => undef,
   native_variant => undef,
   quarter_format_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "K\N{U+0254}ta1",
+    "K\N{U+0254}ta2",
+    "K\N{U+0254}ta3",
+    "K\N{U+0254}ta4",
   ],
   quarter_format_narrow => [
     1,
@@ -238,16 +238,16 @@
     4,
   ],
   quarter_format_wide => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "K\N{U+0254}ta a \N{U+025b}di kan",
+    "k\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmienu",
+    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmi\N{U+025b}nsa",
+    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so nnan",
   ],
   quarter_stand_alone_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "K\N{U+0254}ta1",
+    "K\N{U+0254}ta2",
+    "K\N{U+0254}ta3",
+    "K\N{U+0254}ta4",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -256,10 +256,10 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "K\N{U+0254}ta a \N{U+025b}di kan",
+    "k\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmienu",
+    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmi\N{U+025b}nsa",
+    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so nnan",
   ],
   script => undef,
   territory => undef,
@@ -268,5 +268,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => "44.1",
+  version => 46,
 }
