@@ -4,41 +4,41 @@
     "\N{U+12a8}\N{U+1230}\N{U+12d3}\N{U+1275}",
   ],
   available_formats => {
-    Bh => "h B",
-    Bhm => "h:mm B",
-    Bhms => "h:mm:ss B",
+    Bh => "B h",
+    Bhm => "B h:mm",
+    Bhms => "B h:mm:ss",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
+    EBhm => "E B h:mm",
+    EBhms => "E B h:mm:ss",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E a h:mm",
+    Ehms => "E a h:mm:ss",
     Gy => "y G",
     GyMMM => "MMM y G",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
-    GyMd => "M/d/y GGGGG",
+    GyMMMEd => "E MMM d y G",
+    GyMMMd => "MMM d y G",
+    GyMd => "d/M/y GGGGG",
     H => "H",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E\N{U+1363} M/d",
+    MEd => "E\N{U+1363} d/M",
     MMM => "LLL",
     MMMEd => "E\N{U+1363} MMM d",
     MMMMEd => "E\N{U+1363} MMMM d",
-    "MMMMW-count-one" => "\N{U+1233}\N{U+121d}\N{U+1295}\N{U+1275} W \N{U+12e8} MMMM",
-    "MMMMW-count-other" => "\N{U+1233}\N{U+121d}\N{U+1295}\N{U+1275} W \N{U+12e8} MMMM",
+    "MMMMW-count-one" => "\N{U+12e8}MMMM W\N{U+129b} \N{U+1233}\N{U+121d}\N{U+1295}\N{U+1275}",
+    "MMMMW-count-other" => "\N{U+12e8}MMMM W\N{U+129b} \N{U+1233}\N{U+121d}\N{U+1295}\N{U+1275}",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
-    Md => "M/d",
+    Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
+    h => "a h",
+    hm => "a h:mm",
+    hms => "a h:mm:ss",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
@@ -48,14 +48,15 @@
     yMMM => "MMM y",
     yMMMEd => "E\N{U+1363} MMM d y",
     yMMMM => "MMMM y",
-    yMMMd => "d MMM y",
+    yMMMd => "MMM d y",
     yMd => "d/M/y",
-    yQQQ => "QQQ y",
-    yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    yQQQ => "y QQQ",
+    yQQQQ => "y QQQQ",
+    "yw-count-one" => "\N{U+12e8}Y w\N{U+129b} \N{U+1233}\N{U+121d}\N{U+1295}\N{U+1275}",
+    "yw-count-other" => "\N{U+12e8}Y w\N{U+129b} \N{U+1233}\N{U+121d}\N{U+1295}\N{U+1275}",
   },
   code => "am",
-  date_format_full => "y MMMM d, EEEE",
+  date_format_full => "EEEE d MMMM y",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "dd/MM/y",
@@ -269,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
