@@ -41,7 +41,7 @@
     MMdd => "dd\N{U+200f}/MM",
     Md => "d\N{U+200f}/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -140,7 +140,7 @@
     "\N{U+0642}\N{U+0628}\N{U+0644} \N{U+0627}\N{U+0644}\N{U+0645}\N{U+064a}\N{U+0644}\N{U+0627}\N{U+062f}",
     "\N{U+0645}\N{U+064a}\N{U+0644}\N{U+0627}\N{U+062f}\N{U+064a}",
   ],
-  first_day_of_week => 6,
+  first_day_of_week => 1,
   glibc_date_1_format => "%d %b, %Y %Z %I:%M:%S %p",
   glibc_date_format => "%d %b, %Y",
   glibc_datetime_format => "%d %b, %Y %I:%M:%S %p",
@@ -280,5 +280,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
