@@ -34,7 +34,7 @@
     MMMd => "MMM d",
     Md => "MM-dd",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -46,8 +46,8 @@
     yMMM => "y MMM",
     yMMMEd => "y MMM d, E",
     yMMMM => "y MMMM",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
+    yMMMd => "d MMM y",
+    yMd => "dd-MM-y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
     "yw-count-other" => "'week' w 'of' Y",
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
