@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "AM",
-    "PM",
+    "a.\N{U+202f}m.",
+    "p.\N{U+202f}m.",
   ],
   available_formats => {
     Bh => "h B",
@@ -19,14 +19,14 @@
     GyMMM => "MMM y. G",
     GyMMMEd => "E, d. MMM y. G",
     GyMMMd => "d. MMM y. G",
-    GyMd => "d/M/y. G",
+    GyMd => "d. M. y. G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss (v)",
     Hmv => "HH:mm (v)",
     M => "L",
-    MEd => "E, d.M.",
+    MEd => "E, d. M.",
     MMM => "LLL",
     MMMEd => "E, d. MMM",
     MMMMEd => "E, d. MMMM",
@@ -36,7 +36,7 @@
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMdd => "d. M.",
-    Md => "d.M.",
+    Md => "d. M.",
     d => "d.",
     h => "h\N{U+202f}a",
     hm => "hh:mm\N{U+202f}a",
@@ -46,13 +46,13 @@
     ms => "mm:ss",
     y => "y.",
     yM => "MM/y",
-    yMEd => "E, d.M.y.",
-    yMM => "M/y",
+    yMEd => "E, d. M. y.",
+    yMM => "M. y.",
     yMMM => "MMM y.",
     yMMMEd => "E, d. MMM y.",
     yMMMM => "LLLL y.",
     yMMMd => "d. MMM y.",
-    yMd => "d.M.y.",
+    yMd => "d. M. y.",
     yQQQ => "QQQ y.",
     yQQQQ => "QQQQ y.",
     "yw-count-few" => "w. 'sedmica' 'u' Y.",
@@ -274,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
