@@ -173,7 +173,7 @@
     "Hunyo",
     "Hulyo",
     "Agosto",
-    "Septiyembre",
+    "Septyembre",
     "Oktubre",
     "Nobyembre",
     "Disyembre",
@@ -215,7 +215,7 @@
     "Hunyo",
     "Hulyo",
     "Agosto",
-    "Septiyembre",
+    "Septyembre",
     "Oktubre",
     "Nobyembre",
     "Disyembre",
@@ -269,5 +269,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
