@@ -22,7 +22,7 @@
     GyMMMEEEEd => "EEEE d MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
-    GyMd => "d/M/y GGGGG",
+    GyMd => "d/M/y G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -68,7 +68,7 @@
     "yw-count-other" => "'week' w 'of' Y",
   },
   code => "en-AU",
-  date_format_full => "EEEE d MMMM y",
+  date_format_full => "EEEE, d MMMM y",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "d/M/yy",
@@ -282,5 +282,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
