@@ -17,10 +17,10 @@
     Ehms => "E h.mm.ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "LLL y G",
-    GyMMMEd => "E d. MMM y G",
+    GyMMMEd => "E d.M.y G",
     GyMMMMEd => "E d. MMMM y G",
     GyMMMMd => "d. MMMM y G",
-    GyMMMd => "d. MMM y G",
+    GyMMMd => "d.M.y G",
     GyMd => "M.d.y G",
     H => "H",
     Hm => "H.mm",
@@ -30,12 +30,12 @@
     M => "L",
     MEd => "E d.M.",
     MMM => "LLL",
-    MMMEd => "ccc d. MMM",
+    MMMEd => "ccc d.M.",
     MMMMEd => "ccc d. MMMM",
     "MMMMW-count-one" => "LLLL'n' W. 'viikko'",
     "MMMMW-count-other" => "LLLL'n' W. 'viikko'",
     MMMMd => "d. MMMM",
-    MMMd => "d. MMM",
+    MMMd => "d.M.",
     Md => "d.M.",
     d => "d",
     h => "h\N{U+202f}a",
@@ -49,12 +49,12 @@
     yMEd => "E d.M.y",
     yMM => "M.y",
     yMMM => "LLL y",
-    yMMMEd => "E d. MMM y",
+    yMMMEd => "E d.M.y",
     yMMMM => "LLLL y",
     yMMMMEd => "E d. MMMM y",
     yMMMMccccd => "cccc d. MMMM y",
     yMMMMd => "d. MMMM y",
-    yMMMd => "d. MMM y",
+    yMMMd => "d.M.y",
     yMd => "d.M.y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
@@ -95,7 +95,7 @@
     "torstaina",
     "perjantaina",
     "lauantaina",
-    "sunnuntaina",
+    "sunnuntai",
   ],
   day_stand_alone_abbreviated => [
     "ma",
@@ -144,18 +144,18 @@
   glibc_time_format => "%H.%M.%S",
   language => "Finnish",
   month_format_abbreviated => [
-    "tammik.",
-    "helmik.",
-    "maalisk.",
-    "huhtik.",
-    "toukok.",
-    "kes\N{U+00e4}k.",
-    "hein\N{U+00e4}k.",
-    "elok.",
-    "syysk.",
-    "lokak.",
-    "marrask.",
-    "jouluk.",
+    "tammi",
+    "helmi",
+    "maalis",
+    "huhti",
+    "touko",
+    "kes\N{U+00e4}",
+    "hein\N{U+00e4}",
+    "elo",
+    "syys",
+    "loka",
+    "marras",
+    "joulu",
   ],
   month_format_narrow => [
     "T",
@@ -276,5 +276,5 @@
   time_format_medium => "H.mm.ss",
   time_format_short => "H.mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
