@@ -34,7 +34,7 @@
     MMMd => "MMM d",
     Md => "MM-dd",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -46,8 +46,8 @@
     yMMM => "y MMM",
     yMMMEd => "y MMM d, E",
     yMMMM => "y MMMM",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
+    yMMMd => "MMM d, y",
+    yMd => "M/d/y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
     "yw-count-other" => "'week' w 'of' Y",
@@ -62,13 +62,13 @@
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Ju",
+    "Juf\N{U+0254}",
+    "Sh\N{U+0254}",
+    "Soo",
+    "Sohaa",
+    "H\N{U+0254}\N{U+0254}",
+    "H\N{U+0254}gbaa",
   ],
   day_format_narrow => [
     "M",
@@ -80,22 +80,22 @@
     "S",
   ],
   day_format_wide => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Ju",
+    "Juf\N{U+0254}",
+    "Sh\N{U+0254}",
+    "Soo",
+    "Sohaa",
+    "H\N{U+0254}\N{U+0254}",
+    "H\N{U+0254}gbaa",
   ],
   day_stand_alone_abbreviated => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Ju",
+    "Juf\N{U+0254}",
+    "Sh\N{U+0254}",
+    "Soo",
+    "Sohaa",
+    "H\N{U+0254}\N{U+0254}",
+    "H\N{U+0254}gbaa",
   ],
   day_stand_alone_narrow => [
     "M",
@@ -107,13 +107,13 @@
     "S",
   ],
   day_stand_alone_wide => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Ju",
+    "Juf\N{U+0254}",
+    "Sh\N{U+0254}",
+    "Soo",
+    "Sohaa",
+    "H\N{U+0254}\N{U+0254}",
+    "H\N{U+0254}gbaa",
   ],
   era_abbreviated => [
     "BCE",
@@ -135,18 +135,18 @@
   glibc_time_format => "%H:%M:%S",
   language => "Ga",
   month_format_abbreviated => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Aharabata",
+    "Ofl\N{U+0254}",
+    "Otsokrikri",
+    "Ab\N{U+025b}ibe",
+    "Agbi\N{U+025b}naa",
+    "Otukwaja\N{U+014b}",
+    "Maaw\N{U+025b}",
+    "Manyawale",
+    "Gbo",
+    "Ant\N{U+0254}\N{U+014b}",
+    "Alemle",
+    "Afuabe",
   ],
   month_format_narrow => [
     1,
@@ -163,32 +163,32 @@
     12,
   ],
   month_format_wide => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Aharabata",
+    "Ofl\N{U+0254}",
+    "Otsokrikri",
+    "Ab\N{U+025b}ibe",
+    "Agbi\N{U+025b}naa",
+    "Otukwaja\N{U+014b}",
+    "Maaw\N{U+025b}",
+    "Manyawale",
+    "Gbo",
+    "Ant\N{U+0254}\N{U+014b}",
+    "Alemle",
+    "Afuabe",
   ],
   month_stand_alone_abbreviated => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Aharabata",
+    "Ofl\N{U+0254}",
+    "Otsokrikri",
+    "Ab\N{U+025b}ibe",
+    "Agbi\N{U+025b}naa",
+    "Otukwaja\N{U+014b}",
+    "Maaw\N{U+025b}",
+    "Manyawale",
+    "Gbo",
+    "Ant\N{U+0254}\N{U+014b}",
+    "Alemle",
+    "Afuabe",
   ],
   month_stand_alone_narrow => [
     1,
@@ -205,18 +205,18 @@
     12,
   ],
   month_stand_alone_wide => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Aharabata",
+    "Ofl\N{U+0254}",
+    "Otsokrikri",
+    "Ab\N{U+025b}ibe",
+    "Agbi\N{U+025b}naa",
+    "Otukwaja\N{U+014b}",
+    "Maaw\N{U+025b}",
+    "Manyawale",
+    "Gbo",
+    "Ant\N{U+0254}\N{U+014b}",
+    "Alemle",
+    "Afuabe",
   ],
   name => "Ga",
   native_language => "G\N{U+00e3}",
@@ -262,10 +262,10 @@
   ],
   script => undef,
   territory => undef,
-  time_format_full => "HH:mm:ss zzzz",
-  time_format_long => "HH:mm:ss z",
-  time_format_medium => "HH:mm:ss",
-  time_format_short => "HH:mm",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
