@@ -19,7 +19,7 @@
     "Ehms-alt-ascii" => "E, h:mm:ss a",
     Gy => "G y",
     GyMMM => "G y MMM",
-    GyMMMEEEEd => "EEEE d MMM, y G",
+    GyMMMEEEEd => "G y, dd MMMM, E",
     GyMMMEd => "G y, dd MMM, E",
     GyMMMd => "G y, d MMM",
     GyMd => "d/M/y G",
@@ -31,9 +31,9 @@
     M => "L",
     MEd => "E, dd/MM",
     MMM => "LLL",
-    MMMEEEEd => "EEEE d MMM",
+    MMMEEEEd => "EEEE, d MMM",
     MMMEd => "E, d MMM",
-    MMMMEEEEd => "EEEE d MMMM",
+    MMMMEEEEd => "EEEE, d MMMM",
     "MMMMW-count-one" => "MMMM 'kaa' 'week' W",
     "MMMMW-count-other" => "MMMM 'kaa' 'week' W",
     MMMMd => "d MMMM",
@@ -56,10 +56,10 @@
     yM => "MM/y",
     yMEd => "E, d/M/y",
     yMMM => "MMM y",
-    yMMMEEEEd => "EEEE d MMM, y",
+    yMMMEEEEd => "EEEE, d MMM y",
     yMMMEd => "E, d MMM, y",
     yMMMM => "MMMM y",
-    yMMMMEEEEd => "EEEE d MMMM, y",
+    yMMMMEEEEd => "EEEE, d MMMM y",
     yMMMd => "d MMM, y",
     yMd => "d/M/y",
     yQQQ => "QQQ y",
@@ -68,7 +68,7 @@
     "yw-count-other" => "Y 'kaa' 'week' w",
   },
   code => "hi-Latn",
-  date_format_full => "EEEE d MMMM, y",
+  date_format_full => "EEEE, d MMMM y",
   date_format_long => "d MMMM, y",
   date_format_medium => "dd MMM, y",
   date_format_short => "dd/MM/y",
@@ -282,5 +282,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
