@@ -31,11 +31,11 @@
     MMMEd => "d MMM, E",
     "MMMMW-count-one" => "MMMM W-\N{U+056b}\N{U+0576} \N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
     "MMMMW-count-other" => "MMMM W-\N{U+0580}\N{U+0564} \N{U+0577}\N{U+0561}\N{U+0562}\N{U+0561}\N{U+0569}",
-    MMMMd => "MMMM d",
+    MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "dd.MM",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -269,5 +269,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
