@@ -12,41 +12,41 @@
     EBhms => "E h:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
-    Ed => "d, E",
+    Ed => "d\N{U+a44d}, E",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
     Gy => "G y",
     GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    GyMMMEd => "G y MMM d\N{U+a44d},E",
+    GyMMMd => "G y MMM d\N{U+a44d}",
     GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
-    Hmsv => "HH:mm:ss v",
+    Hmsv => "v HH:mm:ss",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "MM-dd, E",
+    MEd => "MM\N{U+a1aa}-dd\N{U+a44d}\N{U+ff0c}E",
     MMM => "LLL",
-    MMMEd => "MMM d, E",
+    MMMEd => "MMMM d\N{U+a44d},E",
     "MMMMW-count-other" => "'week' W 'of' MMMM",
-    MMMMd => "MMMM d",
-    MMMd => "MMM d",
-    Md => "MM-dd",
-    d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
+    MMMMd => "MMMM d\N{U+a44d}",
+    MMMd => "MMM d\N{U+a44d}",
+    Md => "MM\N{U+a1aa}-dd\N{U+a44d}",
+    d => "d\N{U+a44d}",
+    h => "h\N{U+202f}a",
+    hm => "ah:mm",
+    hms => "ah:mm:ss",
+    hmsv => "v ah:mm:ss",
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
     yM => "y-MM",
     yMEd => "y-MM-dd, E",
     yMMM => "y MMM",
-    yMMMEd => "y MMM d, E",
+    yMMMEd => "y MMM d\N{U+a44d},E",
     yMMMM => "y MMMM",
-    yMMMd => "y MMM d",
+    yMMMd => "y\N{U+a20e}M\N{U+a1aa}d\N{U+a44d}",
     yMd => "y-MM-dd",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
@@ -68,7 +68,7 @@
     "\N{U+a18f}\N{U+a1d6}",
     "\N{U+a18f}\N{U+a26c}",
     "\N{U+a18f}\N{U+a0d8}",
-    "\N{U+a46d}\N{U+a18f}",
+    "\N{U+a46c}\N{U+a18f}",
   ],
   day_format_narrow => [
     "\N{U+a2cd}",
@@ -86,7 +86,7 @@
     "\N{U+a18f}\N{U+a282}\N{U+a1d6}",
     "\N{U+a18f}\N{U+a282}\N{U+a26c}",
     "\N{U+a18f}\N{U+a282}\N{U+a0d8}",
-    "\N{U+a46d}\N{U+a18f}\N{U+a44d}",
+    "\N{U+a46c}\N{U+a18f}\N{U+a44d}",
   ],
   day_stand_alone_abbreviated => [
     "\N{U+a18f}\N{U+a2cd}",
@@ -95,7 +95,7 @@
     "\N{U+a18f}\N{U+a1d6}",
     "\N{U+a18f}\N{U+a26c}",
     "\N{U+a18f}\N{U+a0d8}",
-    "\N{U+a46d}\N{U+a18f}",
+    "\N{U+a46c}\N{U+a18f}",
   ],
   day_stand_alone_narrow => [
     "\N{U+a2cd}",
@@ -113,7 +113,7 @@
     "\N{U+a18f}\N{U+a282}\N{U+a1d6}",
     "\N{U+a18f}\N{U+a282}\N{U+a26c}",
     "\N{U+a18f}\N{U+a282}\N{U+a0d8}",
-    "\N{U+a46d}\N{U+a18f}\N{U+a44d}",
+    "\N{U+a46c}\N{U+a18f}\N{U+a44d}",
   ],
   era_abbreviated => [
     "\N{U+a0c5}\N{U+a2ca}\N{U+a0bf}",
@@ -145,7 +145,7 @@
     "\N{U+a246}\N{U+a1aa}",
     "\N{U+a22c}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a1aa}",
-    "\N{U+a2b0}\N{U+a2aa}\N{U+a1aa}",
+    "\N{U+a2af}\N{U+a2aa}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a44b}\N{U+a1aa}",
   ],
   month_format_narrow => [
@@ -173,7 +173,7 @@
     "\N{U+a246}\N{U+a1aa}",
     "\N{U+a22c}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a1aa}",
-    "\N{U+a2b0}\N{U+a2aa}\N{U+a1aa}",
+    "\N{U+a2af}\N{U+a2aa}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a44b}\N{U+a1aa}",
   ],
   month_stand_alone_abbreviated => [
@@ -187,7 +187,7 @@
     "\N{U+a246}\N{U+a1aa}",
     "\N{U+a22c}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a1aa}",
-    "\N{U+a2b0}\N{U+a2aa}\N{U+a1aa}",
+    "\N{U+a2af}\N{U+a2aa}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a44b}\N{U+a1aa}",
   ],
   month_stand_alone_narrow => [
@@ -215,7 +215,7 @@
     "\N{U+a246}\N{U+a1aa}",
     "\N{U+a22c}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a1aa}",
-    "\N{U+a2b0}\N{U+a2aa}\N{U+a1aa}",
+    "\N{U+a2af}\N{U+a2aa}\N{U+a1aa}",
     "\N{U+a2b0}\N{U+a44b}\N{U+a1aa}",
   ],
   name => "Sichuan Yi China",
@@ -225,10 +225,10 @@
   native_territory => "\N{U+a34f}\N{U+a1e9}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+a0c5}\N{U+a44c}",
-    "\N{U+a0c5}\N{U+a3b8}",
-    "\N{U+a0c5}\N{U+a375}",
-    "\N{U+a0c5}\N{U+a2c6}",
+    "1\N{U+a12e}\N{U+a430}",
+    "2\N{U+a12e}\N{U+a430}",
+    "3\N{U+a12e}\N{U+a430}",
+    "4\N{U+a12e}\N{U+a430}",
   ],
   quarter_format_narrow => [
     1,
@@ -237,16 +237,16 @@
     4,
   ],
   quarter_format_wide => [
-    "\N{U+a0c5}\N{U+a44c}",
-    "\N{U+a0c5}\N{U+a3b8}",
-    "\N{U+a0c5}\N{U+a375}",
-    "\N{U+a0c5}\N{U+a2c6}",
+    "\N{U+a12e}\N{U+a430}\N{U+a2cd}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
+    "\N{U+a12e}\N{U+a430}\N{U+a44d}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
+    "\N{U+a12e}\N{U+a430}\N{U+a315}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
+    "\N{U+a12e}\N{U+a430}\N{U+a1d6}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+a0c5}\N{U+a44c}",
-    "\N{U+a0c5}\N{U+a3b8}",
-    "\N{U+a0c5}\N{U+a375}",
-    "\N{U+a0c5}\N{U+a2c6}",
+    1,
+    2,
+    3,
+    4,
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -255,10 +255,10 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "\N{U+a0c5}\N{U+a44c}",
-    "\N{U+a0c5}\N{U+a3b8}",
-    "\N{U+a0c5}\N{U+a375}",
-    "\N{U+a0c5}\N{U+a2c6}",
+    "\N{U+a12e}\N{U+a430}\N{U+a2cd}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
+    "\N{U+a12e}\N{U+a430}\N{U+a44d}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
+    "\N{U+a12e}\N{U+a430}\N{U+a315}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
+    "\N{U+a12e}\N{U+a430}\N{U+a1d6}\N{U+a0b7}\N{U+a0b6}\N{U+a320}",
   ],
   script => undef,
   territory => "China",
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
