@@ -30,11 +30,11 @@
     MMM => "LLL",
     MMMEd => "E d MMM",
     "MMMMW-count-other" => "\N{U+179f}\N{U+1794}\N{U+17d2}\N{U+178f}\N{U+17b6}\N{U+17a0}\N{U+17cd}\N{U+1791}\N{U+17b8} W \N{U+1793}\N{U+17c3}\N{U+1781}\N{U+17c2} MMMM",
-    MMMMd => "MMMM d",
+    MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -267,5 +267,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
