@@ -31,10 +31,10 @@
     MMMEd => "E, d MMM",
     "MMMMW-count-other" => "'week' W 'of' MMMM",
     MMMMd => "d MMMM",
-    MMMd => "MMM d",
+    MMMd => "d MMM",
     Md => "d-M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -43,10 +43,10 @@
     y => "y",
     yM => "M-y",
     yMEd => "d-M-y, E",
-    yMMM => "y MMM",
+    yMMM => "MMM, y",
     yMMMEd => "y MMM d, E",
     yMMMM => "MMMM, y",
-    yMMMd => "y MMM d",
+    yMMMd => "d MMM, y",
     yMd => "d-M-y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
@@ -120,7 +120,7 @@
     "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}.\N{U+0936}.",
   ],
   era_narrow => [
-    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}\N{U+0938}\N{U+094d}\N{U+0924}\N{U+092a}\N{U+0942}\N{U+0930}\N{U+094d}\N{U+0935}",
+    "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}.\N{U+0906}.",
     "\N{U+0915}\N{U+094d}\N{U+0930}\N{U+093f}.\N{U+0936}.",
   ],
   era_wide => [
@@ -267,5 +267,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
