@@ -1,24 +1,24 @@
 {
   am_pm_abbreviated => [
-    "AM",
-    "PM",
+    "\N{U+090f}\N{U+202f}\N{U+090f}\N{U+092e}",
+    "\N{U+092a}\N{U+0940}\N{U+202f}\N{U+090f}\N{U+092e}",
   ],
   available_formats => {
-    Bh => "h B",
-    Bhm => "h:mm B",
-    Bhms => "h:mm:ss B",
+    Bh => "B h",
+    Bhm => "B h:mm",
+    Bhms => "B h:mm:ss",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
+    EBhm => "E B h:mm",
+    EBhms => "E B h:mm:ss",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
-    Ed => "d, E",
+    Ed => "E d",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
-    Gy => "G y",
-    GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    Gy => "y G",
+    GyMMM => "MMM G y",
+    GyMMMEd => "E, d MMM y G",
+    GyMMMd => "d MMM y G",
     GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
@@ -26,58 +26,58 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "MM-dd, E",
+    MEd => "E, d/M",
     MMM => "LLL",
-    MMMEd => "MMM d, E",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
-    MMMMd => "MMMM d",
-    MMMd => "MMM d",
-    Md => "MM-dd",
+    MMMEd => "E, d MMM",
+    "MMMMW-count-other" => "MMMM \N{U+0924}\N{U+093e}\N{U+0901} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e} W",
+    MMMMd => "d MMMM",
+    MMMd => "d MMM",
+    Md => "d/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
-    yM => "y-MM",
-    yMEd => "y-MM-dd, E",
-    yMMM => "y MMM",
-    yMMMEd => "y MMM d, E",
-    yMMMM => "y MMMM",
+    yM => "M/y",
+    yMEd => "E, d/M/y",
+    yMMM => "MMM y",
+    yMMMEd => "E, d MMM y",
+    yMMMM => "MMMM y",
     yMMMd => "d MMM y",
     yMd => "d/M/y",
-    yQQQ => "y QQQ",
-    yQQQQ => "y QQQQ",
-    "yw-count-other" => "'week' w 'of' Y",
+    yQQQ => "QQQ y",
+    yQQQQ => "QQQQ y",
+    "yw-count-other" => "Y \N{U+0924}\N{U+093e}\N{U+0901} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e} w",
   },
   code => "kxv-Deva",
-  date_format_full => "y MMMM d, EEEE",
-  date_format_long => "y MMMM d",
-  date_format_medium => "y MMM d",
-  date_format_short => "y-MM-dd",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  date_format_full => "EEEE, d MMMM y",
+  date_format_long => "d MMMM y",
+  date_format_medium => "d MMM y",
+  date_format_short => "d/M/yy",
+  datetime_format_full => "{1} \N{U+0906}\N{U+0901} {0}",
+  datetime_format_long => "{1} \N{U+0906}\N{U+0901} {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
-    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+093e}",
-    "\N{U+092a}\N{U+0941}\N{U+0926}\N{U+094d}\N{U+0926}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0906}\N{U+0926}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
+    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
+    "\N{U+092e}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0917}\N{U+093e}",
+    "\N{U+092a}\N{U+0942}\N{U+0926}\N{U+093e}",
+    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+0940}",
+    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941}",
+    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f}",
+    "\N{U+0906}\N{U+0926}\N{U+093f}",
   ],
   day_format_narrow => [
-    "M",
-    "T",
-    "W",
-    "T",
-    "F",
-    "S",
-    "S",
+    "\N{U+0938}\N{U+093e}\N{U+0945}",
+    "\N{U+092e}\N{U+093e}",
+    "\N{U+092a}\N{U+0942}",
+    "\N{U+0932}\N{U+093e}",
+    "\N{U+0938}\N{U+0941}",
+    "\N{U+0938}\N{U+093e}",
+    "\N{U+0906}",
   ],
   day_format_wide => [
     "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
@@ -89,22 +89,22 @@
     "\N{U+0906}\N{U+0926}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
   ],
   day_stand_alone_abbreviated => [
-    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+093e}",
-    "\N{U+092a}\N{U+0941}\N{U+0926}\N{U+094d}\N{U+0926}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
-    "\N{U+0906}\N{U+0926}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
+    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
+    "\N{U+092e}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0917}\N{U+093e}",
+    "\N{U+092a}\N{U+0942}\N{U+0926}\N{U+093e}",
+    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+0940}",
+    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941}",
+    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f}",
+    "\N{U+0906}\N{U+0926}\N{U+093f}",
   ],
   day_stand_alone_narrow => [
-    "M",
-    "T",
-    "W",
-    "T",
-    "F",
-    "S",
-    "S",
+    "\N{U+0938}\N{U+093e}\N{U+0945}",
+    "\N{U+092e}\N{U+093e}",
+    "\N{U+092a}\N{U+0942}",
+    "\N{U+0932}\N{U+093e}",
+    "\N{U+0938}\N{U+0941}",
+    "\N{U+0938}\N{U+093e}",
+    "\N{U+0906}",
   ],
   day_stand_alone_wide => [
     "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
@@ -116,16 +116,16 @@
     "\N{U+0906}\N{U+0926}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
   ],
   era_abbreviated => [
-    "BCE",
-    "CE",
+    "\N{U+092c}\N{U+093f}\N{U+0938}\N{U+093f}",
+    "\N{U+090f}-\N{U+0921}\N{U+093f}",
   ],
   era_narrow => [
-    "BCE",
-    "CE",
+    "\N{U+092c}\N{U+093f}\N{U+0938}\N{U+093f}",
+    "\N{U+090f}-\N{U+0921}\N{U+093f}",
   ],
   era_wide => [
-    "BCE",
-    "CE",
+    "\N{U+092c}\N{U+093f}\N{U+092b}\N{U+094b}\N{U+0930} \N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0907}\N{U+0938}\N{U+094d}\N{U+091f}",
+    "\N{U+0905}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+094b} \N{U+0921}\N{U+094b}\N{U+092e}\N{U+093f}\N{U+0928}\N{U+0940}",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -135,32 +135,32 @@
   glibc_time_format => "%H:%M:%S",
   language => "Kuvi",
   month_format_abbreviated => [
-    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}\N{U+0915}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}\N{U+0923}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+094b} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0926}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
+    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941}",
+    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}",
+    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}",
+    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+094d}\N{U+0930}\N{U+0947}",
+    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947}",
+    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+094d}\N{U+091f}\N{U+093e}",
+    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940}",
+    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901}",
+    "\N{U+092c}\N{U+093e}\N{U+0945}\N{U+0926}\N{U+094b}",
+    "\N{U+0926}\N{U+093e}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e}",
+    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940}",
+    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947}",
   ],
   month_format_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "\N{U+092a}\N{U+0941}",
+    "\N{U+092e}\N{U+093e}",
+    "\N{U+092a}\N{U+093e}",
+    "\N{U+0939}\N{U+093f}",
+    "\N{U+092c}\N{U+0947}",
+    "\N{U+091c}\N{U+093e}",
+    "\N{U+0906}",
+    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}",
+    "\N{U+092c}\N{U+093e}\N{U+0945}",
+    "\N{U+0926}\N{U+093e}",
+    "\N{U+0926}\N{U+093f}",
+    "\N{U+092a}\N{U+093e}",
   ],
   month_format_wide => [
     "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
@@ -177,32 +177,32 @@
     "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
   ],
   month_stand_alone_abbreviated => [
-    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}\N{U+0915}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}\N{U+0923}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+094b} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0926}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
-    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
+    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941}",
+    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}",
+    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}",
+    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+094d}\N{U+0930}\N{U+0947}",
+    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947}",
+    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+094d}\N{U+091f}\N{U+093e}",
+    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940}",
+    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901}",
+    "\N{U+092c}\N{U+093e}\N{U+0945}\N{U+0926}\N{U+094b}",
+    "\N{U+0926}\N{U+093e}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e}",
+    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940}",
+    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947}",
   ],
   month_stand_alone_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "\N{U+092a}\N{U+0941}",
+    "\N{U+092e}\N{U+093e}",
+    "\N{U+092a}\N{U+093e}",
+    "\N{U+0939}\N{U+093f}",
+    "\N{U+092c}\N{U+0947}",
+    "\N{U+091c}\N{U+093e}",
+    "\N{U+0906}",
+    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}",
+    "\N{U+092c}\N{U+093e}\N{U+0945}",
+    "\N{U+0926}\N{U+093e}",
+    "\N{U+0926}\N{U+093f}",
+    "\N{U+092a}\N{U+093e}",
   ],
   month_stand_alone_wide => [
     "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
@@ -225,10 +225,10 @@
   native_territory => undef,
   native_variant => undef,
   quarter_format_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0915} \N{U+0967}",
+    "\N{U+0915} \N{U+0968}",
+    "\N{U+0915} \N{U+0969}",
+    "\N{U+0915} \N{U+096a}",
   ],
   quarter_format_narrow => [
     1,
@@ -237,16 +237,16 @@
     4,
   ],
   quarter_format_wide => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0967}\N{U+0938}\N{U+094d}\N{U+091f} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
+    "\N{U+0968} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
+    "\N{U+0969}\N{U+0930}\N{U+094d}\N{U+0921} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
+    "\N{U+096a}\N{U+0925} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
   ],
   quarter_stand_alone_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0915} \N{U+0967}",
+    "\N{U+0915} \N{U+0968}",
+    "\N{U+0915} \N{U+0969}",
+    "\N{U+0915} \N{U+096a}",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -255,17 +255,17 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0967}\N{U+0938}\N{U+094d}\N{U+091f} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
+    "\N{U+0968} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
+    "\N{U+0969}\N{U+0930}\N{U+094d}\N{U+0921} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
+    "\N{U+096a}\N{U+0925} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
   ],
   script => "Devanagari",
   territory => undef,
-  time_format_full => "HH:mm:ss zzzz",
-  time_format_long => "HH:mm:ss z",
-  time_format_medium => "HH:mm:ss",
-  time_format_short => "HH:mm",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
