@@ -5,7 +5,7 @@
   ],
   available_formats => {
     Bh => "B h",
-    Bhm => ">B h:mm",
+    Bhm => "B h:mm",
     Bhms => "B h:mm:ss",
     E => "ccc",
     EBhm => "E B h:mm",
@@ -29,12 +29,12 @@
     MEd => "E, d/M",
     MMM => "LLL",
     MMMEd => "E, d MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-other" => "MMMM 't\N{U+00e3}' 'vara' W",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -50,7 +50,7 @@
     yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-other" => "Y 't\N{U+00e3}' 'vara' w",
   },
   code => "kxv-Latn",
   date_format_full => "EEEE, d MMMM y",
@@ -267,5 +267,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
