@@ -1,24 +1,24 @@
 {
   am_pm_abbreviated => [
-    "AM",
-    "PM",
+    "\N{U+0c0e}\N{U+202f}\N{U+0c0e}\N{U+0c2e}\N{U+0c4d}",
+    "\N{U+0c2a}\N{U+0c3f}\N{U+202f}\N{U+0c0e}\N{U+0c2e}\N{U+0c4d}",
   ],
   available_formats => {
-    Bh => "h B",
-    Bhm => "h:mm B",
-    Bhms => "h:mm:ss B",
+    Bh => "B h",
+    Bhm => "B h:mm",
+    Bhms => "B h:mm:ss",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
+    EBhm => "E B h:mm",
+    EBhms => "E B h:mm:ss",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
-    Ed => "d, E",
+    Ed => "E d",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
-    Gy => "G y",
-    GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    Gy => "y G",
+    GyMMM => "MMM G y",
+    GyMMMEd => "E, d MMM y G",
+    GyMMMd => "d MMM y G",
     GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
@@ -26,41 +26,41 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "MM-dd, E",
+    MEd => "E, d/M",
     MMM => "LLL",
-    MMMEd => "MMM d, E",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
-    MMMMd => "MMMM d",
-    MMMd => "MMM d",
-    Md => "MM-dd",
+    MMMEd => "E, d MMM",
+    "MMMMW-count-other" => "MMMM \N{U+0c24}\N{U+0c3f} \N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c3e} W",
+    MMMMd => "d MMMM",
+    MMMd => "d MMM",
+    Md => "d/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
-    yM => "y-MM",
-    yMEd => "y-MM-dd, E",
-    yMMM => "y MMM",
-    yMMMEd => "y MMM d, E",
-    yMMMM => "y MMMM",
+    yM => "M/y",
+    yMEd => "E, d/M/y",
+    yMMM => "MMM y",
+    yMMMEd => "E, d MMM y",
+    yMMMM => "MMMM y",
     yMMMd => "d MMM y",
     yMd => "d/M/y",
-    yQQQ => "y QQQ",
-    yQQQQ => "y QQQQ",
-    "yw-count-other" => "'week' w 'of' Y",
+    yQQQ => "QQQ y",
+    yQQQQ => "QQQQ y",
+    "yw-count-other" => "Y \N{U+0c24}\N{U+0c3f} \N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c3e} w",
   },
   code => "kxv-Telu-IN",
-  date_format_full => "y MMMM d, EEEE",
-  date_format_long => "y MMMM d",
-  date_format_medium => "y MMM d",
-  date_format_short => "y-MM-dd",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  date_format_full => "EEEE, d MMMM y",
+  date_format_long => "d MMMM y",
+  date_format_medium => "d MMM y",
+  date_format_short => "d/M/yy",
+  datetime_format_full => "{1} \N{U+0c24} {0}",
+  datetime_format_long => "{1} \N{U+0c24} {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "\N{U+0c28}\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c3e}",
     "\N{U+0c2e}\N{U+0c3e}\N{U+0c02}\N{U+0c17}\N{U+0c3e}\N{U+0c21}\N{U+0c3e}",
@@ -71,13 +71,13 @@
     "\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c2e}\N{U+0c3f}",
   ],
   day_format_narrow => [
-    "M",
-    "T",
-    "W",
-    "T",
-    "F",
-    "S",
-    "S",
+    "\N{U+0c28}",
+    "\N{U+0c2e}\N{U+0c3e}",
+    "\N{U+0c35}\N{U+0c41}",
+    "\N{U+0c32}",
+    "\N{U+0c28}\N{U+0c41}",
+    "\N{U+0c38}\N{U+0c3e}",
+    "\N{U+0c35}\N{U+0c3e}",
   ],
   day_format_wide => [
     "\N{U+0c28}\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c3e}",
@@ -98,13 +98,13 @@
     "\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c2e}\N{U+0c3f}",
   ],
   day_stand_alone_narrow => [
-    "M",
-    "T",
-    "W",
-    "T",
-    "F",
-    "S",
-    "S",
+    "\N{U+0c28}",
+    "\N{U+0c2e}\N{U+0c3e}",
+    "\N{U+0c35}\N{U+0c41}",
+    "\N{U+0c32}",
+    "\N{U+0c28}\N{U+0c41}",
+    "\N{U+0c38}\N{U+0c3e}",
+    "\N{U+0c35}\N{U+0c3e}",
   ],
   day_stand_alone_wide => [
     "\N{U+0c28}\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c3e}",
@@ -116,16 +116,16 @@
     "\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c2e}\N{U+0c3f}",
   ],
   era_abbreviated => [
-    "BCE",
-    "CE",
+    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c2a}\N{U+0c42}",
+    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c36}",
   ],
   era_narrow => [
-    "BCE",
-    "CE",
+    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c2a}\N{U+0c42}",
+    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c36}",
   ],
   era_wide => [
-    "BCE",
-    "CE",
+    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c28}\N{U+0c4d}\N{U+0c24}\N{U+0c41} \N{U+0c35}\N{U+0c42}\N{U+0c30}\N{U+0c4d}\N{U+0c35}\N{U+0c02}",
+    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c38}\N{U+0c4d}\N{U+0c24}\N{U+0c41} \N{U+0c38}\N{U+0c15}\N{U+0c02}",
   ],
   first_day_of_week => 7,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -149,18 +149,18 @@
     "\N{U+0c2a}\N{U+0c41}\N{U+0c38}\N{U+0c41}",
   ],
   month_format_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "\N{U+0c2e}\N{U+0c3e}",
+    "\N{U+0c17}\N{U+0c41}",
+    "\N{U+0c39}\N{U+0c3f}",
+    "\N{U+0c2c}\N{U+0c46}",
+    "\N{U+0c32}",
+    "\N{U+0c30}\N{U+0c3e}",
+    "\N{U+0c2c}\N{U+0c3e}",
+    "\N{U+0c2c}\N{U+0c3e}",
+    "\N{U+0c05}",
+    "\N{U+0c26}\N{U+0c3f}",
+    "\N{U+0c2a}\N{U+0c3e}",
+    "\N{U+0c2a}\N{U+0c41}",
   ],
   month_format_wide => [
     "\N{U+0c2e}\N{U+0c3e}\N{U+0c17}",
@@ -191,18 +191,18 @@
     "\N{U+0c2a}\N{U+0c41}\N{U+0c38}\N{U+0c41}",
   ],
   month_stand_alone_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "\N{U+0c2e}\N{U+0c3e}",
+    "\N{U+0c17}\N{U+0c41}",
+    "\N{U+0c39}\N{U+0c3f}",
+    "\N{U+0c2c}\N{U+0c46}",
+    "\N{U+0c32}",
+    "\N{U+0c30}\N{U+0c3e}",
+    "\N{U+0c2c}\N{U+0c3e}",
+    "\N{U+0c2c}\N{U+0c3e}",
+    "\N{U+0c05}",
+    "\N{U+0c26}\N{U+0c3f}",
+    "\N{U+0c2a}\N{U+0c3e}",
+    "\N{U+0c2a}\N{U+0c41}",
   ],
   month_stand_alone_wide => [
     "\N{U+0c2e}\N{U+0c3e}\N{U+0c17}",
@@ -225,10 +225,10 @@
   native_territory => "\N{U+0c2c}\N{U+0c3e}\N{U+0c30}\N{U+0c24}\N{U+0c26}\N{U+0c46}\N{U+0c38}\N{U+0c3e}\N{U+0c02}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c67}",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c68}",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c69}",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c6a}",
   ],
   quarter_format_narrow => [
     1,
@@ -237,16 +237,16 @@
     4,
   ],
   quarter_format_wide => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0c67}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
+    "\N{U+0c68}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c30}",
+    "\N{U+0c69}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c30}",
+    "\N{U+0c6a}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c30}",
   ],
   quarter_stand_alone_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c67}",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c68}",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c69}",
+    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c6a}",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -255,17 +255,17 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "\N{U+0c67}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
+    "\N{U+0c68}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c30}",
+    "\N{U+0c69}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c30}",
+    "\N{U+0c6a}\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c30}",
   ],
   script => "Telugu",
   territory => "India",
-  time_format_full => "HH:mm:ss zzzz",
-  time_format_long => "HH:mm:ss z",
-  time_format_medium => "HH:mm:ss",
-  time_format_short => "HH:mm",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
