@@ -15,11 +15,11 @@
     Ed => "E, d",
     Ehm => "E h:mm\N{U+202f}a",
     Ehms => "E h:mm:ss\N{U+202f}a",
-    Gy => "y G",
-    GyMMM => "MMM y G",
-    GyMMMEd => "E, d MMM y G",
-    GyMMMd => "d MMM y G",
-    GyMd => "d.M.y GGGGG",
+    Gy => "y\N{U+202f}'\N{U+0433}'. G",
+    GyMMM => "MMM y\N{U+202f}'\N{U+0433}'. G",
+    GyMMMEd => "E, d MMM y\N{U+202f}'\N{U+0433}'. G",
+    GyMMMd => "d MMM y\N{U+202f}'\N{U+0433}'. G",
+    GyMd => "d.M.y\N{U+202f}'\N{U+0433}'. G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -43,23 +43,23 @@
     hmsv => "h:mm:ss\N{U+202f}a v",
     hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
-    y => "y",
-    yM => "M.y",
-    yMEd => "E, d.M.y",
+    y => "y\N{U+202f}'\N{U+0433}'.",
+    yM => "M.y\N{U+202f}'\N{U+0433}'.",
+    yMEd => "E, d.M.y\N{U+202f}'\N{U+0433}'.",
     yMMM => "MMM y\N{U+202f}'\N{U+0433}'.",
     yMMMEd => "E, d MMM y\N{U+202f}'\N{U+0433}'.",
     yMMMM => "MMMM y\N{U+202f}'\N{U+0433}'.",
     yMMMd => "d MMM y\N{U+202f}'\N{U+0433}'.",
-    yMd => "d.M.y",
+    yMd => "d.M.y\N{U+202f}'\N{U+0433}'.",
     yQQQ => "QQQ y\N{U+202f}'\N{U+0433}'.",
     yQQQQ => "QQQQ y\N{U+202f}'\N{U+0433}'.",
     "yw-count-one" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' Y",
     "yw-count-other" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' Y",
   },
   code => "mk-MK",
-  date_format_full => "EEEE, d MMMM y",
-  date_format_long => "d MMMM y",
-  date_format_medium => "d.M.y",
+  date_format_full => "EEEE, d MMMM y\N{U+202f}'\N{U+0433}'.",
+  date_format_long => "d MMMM y\N{U+202f}'\N{U+0433}'.",
+  date_format_medium => "d.M.y\N{U+202f}'\N{U+0433}'.",
   date_format_short => "d.M.yy",
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
@@ -120,12 +120,12 @@
     "\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+0430}",
   ],
   era_abbreviated => [
-    "\N{U+043f}.\N{U+043d}.\N{U+0435}.",
-    "\N{U+043d}.\N{U+0435}.",
+    "\N{U+043f}\N{U+0440}. \N{U+043d}. \N{U+0435}.",
+    "\N{U+043d}. \N{U+0435}.",
   ],
   era_narrow => [
-    "\N{U+043f}.\N{U+043d}.\N{U+0435}.",
-    "\N{U+043d}.\N{U+0435}.",
+    "\N{U+043f}\N{U+0440}. \N{U+043d}. \N{U+0435}.",
+    "\N{U+043d}. \N{U+0435}.",
   ],
   era_wide => [
     "\N{U+043f}\N{U+0440}\N{U+0435}\N{U+0434} \N{U+043d}\N{U+0430}\N{U+0448}\N{U+0430}\N{U+0442}\N{U+0430} \N{U+0435}\N{U+0440}\N{U+0430}",
@@ -229,10 +229,10 @@
   native_territory => "\N{U+0421}\N{U+0435}\N{U+0432}\N{U+0435}\N{U+0440}\N{U+043d}\N{U+0430} \N{U+041c}\N{U+0430}\N{U+043a}\N{U+0435}\N{U+0434}\N{U+043e}\N{U+043d}\N{U+0438}\N{U+0458}\N{U+0430}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+0458}\N{U+0430}\N{U+043d} \N{U+2013} \N{U+043c}\N{U+0430}\N{U+0440}",
-    "\N{U+0430}\N{U+043f}\N{U+0440} \N{U+2013} \N{U+0458}\N{U+0443}\N{U+043d}",
-    "\N{U+0458}\N{U+0443}\N{U+043b} \N{U+2013} \N{U+0441}\N{U+0435}\N{U+043f}",
-    "\N{U+043e}\N{U+043a}\N{U+0442} \N{U+2013} \N{U+0434}\N{U+0435}\N{U+043a}",
+    "\N{U+0458}\N{U+0430}\N{U+043d}. \N{U+2013} \N{U+043c}\N{U+0430}\N{U+0440}.",
+    "\N{U+0430}\N{U+043f}\N{U+0440}. \N{U+2013} \N{U+0458}\N{U+0443}\N{U+043d}.",
+    "\N{U+0458}\N{U+0443}\N{U+043b}. \N{U+2013} \N{U+0441}\N{U+0435}\N{U+043f}.",
+    "\N{U+043e}\N{U+043a}\N{U+0442}. \N{U+2013} \N{U+0434}\N{U+0435}\N{U+043a}.",
   ],
   quarter_format_narrow => [
     1,
@@ -247,10 +247,10 @@
     "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+0458}\N{U+0430}\N{U+043d} \N{U+2013} \N{U+043c}\N{U+0430}\N{U+0440}",
-    "\N{U+0430}\N{U+043f}\N{U+0440} \N{U+2013} \N{U+0458}\N{U+0443}\N{U+043d}",
-    "\N{U+0458}\N{U+0443}\N{U+043b} \N{U+2013} \N{U+0441}\N{U+0435}\N{U+043f}",
-    "\N{U+043e}\N{U+043a}\N{U+0442} \N{U+2013} \N{U+0434}\N{U+0435}\N{U+043a}",
+    "\N{U+0458}\N{U+0430}\N{U+043d}. \N{U+2013} \N{U+043c}\N{U+0430}\N{U+0440}.",
+    "\N{U+0430}\N{U+043f}\N{U+0440}. \N{U+2013} \N{U+0458}\N{U+0443}\N{U+043d}.",
+    "\N{U+0458}\N{U+0443}\N{U+043b}. \N{U+2013} \N{U+0441}\N{U+0435}\N{U+043f}.",
+    "\N{U+043e}\N{U+043a}\N{U+0442}. \N{U+2013} \N{U+0434}\N{U+0435}\N{U+043a}.",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -271,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
