@@ -29,7 +29,7 @@
     MEd => "E, d-M",
     MMM => "LLL",
     MMMEd => "E, d MMM",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-other" => "'minggu' W 'daripada' MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "dd/MM",
@@ -51,7 +51,7 @@
     yMd => "d/M/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-other" => "'minggu' w 'daripada' Y",
   },
   code => "ms-MY",
   date_format_full => "EEEE, d MMMM y",
@@ -268,5 +268,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
