@@ -13,12 +13,12 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d \N{U+101b}\N{U+1000}\N{U+103a} E",
-    Ehm => "E B h:mm",
-    Ehms => "E B h:mm:ss",
+    Ehm => "E a h:mm",
+    Ehms => "E a h:mm:ss",
     Gy => "G y",
     GyMMM => "G y MMM",
-    GyMMMEd => "G y\N{U+104a} MMM d\N{U+104a} E",
-    GyMMMd => "G y\N{U+104a} MMM d",
+    GyMMMEd => "G y/ MMM d/ E",
+    GyMMMd => "G y MMM d",
     GyMd => "G y/M/d",
     H => "HH",
     Hm => "HH:mm",
@@ -26,37 +26,37 @@
     Hmsv => "v HH:mm:ss",
     Hmv => "v HH:mm",
     M => "L",
-    MEd => "d/M\N{U+104a} E",
+    MEd => "d/M E",
     MMM => "LLL",
-    MMMEd => "MMM d\N{U+104a} E",
-    MMMMEd => "MMMM d \N{U+101b}\N{U+1000}\N{U+103a} E",
+    MMMEd => "MMM d E",
+    MMMMEd => "MMMM d E",
     "MMMMW-count-other" => "MMMM \N{U+101c} W \N{U+1015}\N{U+1010}\N{U+103a}\N{U+1019}\N{U+103c}\N{U+1031}\N{U+102c}\N{U+1000}\N{U+103a}",
     MMMMd => "MMMM d",
-    MMMd => "d MMM",
+    MMMd => "MMM d",
     Md => "d/M",
     d => "d",
-    h => "B h",
-    hm => "B h:mm",
-    hms => "B h:mm:ss",
+    h => "a h",
+    hm => "a h:mm",
+    hms => "a h:mm:ss",
     hmsv => "v a h:mm:ss",
     hmv => "v a h:mm",
     ms => "mm:ss",
     y => "y",
-    yM => "M/y",
-    yMEd => "d/M/y\N{U+104a} E",
-    yMMM => "MMM y",
-    yMMMEd => "y\N{U+104a} MMM d\N{U+104a} E",
+    yM => "y-MM",
+    yMEd => "d/M/y E",
+    yMMM => "y MMM",
+    yMMMEd => "y MMM d E",
     yMMMM => "y MMMM",
-    yMMMd => "y\N{U+104a} MMM d",
+    yMMMd => "y MMM d",
     yMd => "d/M/y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
     "yw-count-other" => "Y \N{U+1001}\N{U+102f} w \N{U+1015}\N{U+1010}\N{U+103a}\N{U+1019}\N{U+103c}\N{U+1031}\N{U+102c}\N{U+1000}\N{U+103a}",
   },
   code => "my-MM",
-  date_format_full => "y\N{U+104a} MMMM d\N{U+104a} EEEE",
-  date_format_long => "y\N{U+104a} MMMM d",
-  date_format_medium => "y\N{U+104a} MMM d",
+  date_format_full => "y MMMM d EEEE",
+  date_format_long => "y MMMM d",
+  date_format_medium => "y MMM d",
   date_format_short => "d/M/yy",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
@@ -226,10 +226,10 @@
   native_territory => "\N{U+1019}\N{U+103c}\N{U+1014}\N{U+103a}\N{U+1019}\N{U+102c}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+1015}\N{U+1011}\N{U+1019} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
-    "\N{U+1012}\N{U+102f}\N{U+1010}\N{U+102d}\N{U+101a} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
-    "\N{U+1010}\N{U+1010}\N{U+102d}\N{U+101a} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
-    "\N{U+1005}\N{U+1010}\N{U+102f}\N{U+1010}\N{U+1039}\N{U+1011} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
+    "Q1",
+    "Q2",
+    "Q3",
+    "Q4",
   ],
   quarter_format_narrow => [
     "\N{U+1015}",
@@ -244,10 +244,10 @@
     "\N{U+1005}\N{U+1010}\N{U+102f}\N{U+1010}\N{U+1039}\N{U+1011} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+1015}\N{U+1011}\N{U+1019} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
-    "\N{U+1012}\N{U+102f}\N{U+1010}\N{U+102d}\N{U+101a} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
-    "\N{U+1010}\N{U+1010}\N{U+102d}\N{U+101a} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
-    "\N{U+1005}\N{U+1010}\N{U+102f}\N{U+1010}\N{U+1039}\N{U+1011} \N{U+101e}\N{U+102f}\N{U+1036}\N{U+1038}\N{U+101c}\N{U+1015}\N{U+1010}\N{U+103a}",
+    "Q1",
+    "Q2",
+    "Q3",
+    "Q4",
   ],
   quarter_stand_alone_narrow => [
     "\N{U+1015}",
@@ -268,5 +268,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
