@@ -16,9 +16,9 @@
     Ehm => "E h:mm\N{U+202f}a",
     Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "G y",
-    GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    GyMMM => "MMM y G",
+    GyMMMEd => "E, MMM d, y G",
+    GyMMMd => "MMM d, y G",
     GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
@@ -26,12 +26,13 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "MM-dd, E",
+    MEd => "E, M/d",
     MMM => "LLL",
-    MMMEd => "MMM d, E",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    MMMEd => "E, MMM d",
+    "MMMMW-count-one" => "'torbee' W 'kan' MMMM",
+    "MMMMW-count-other" => "'torbee' W 'kan' MMMM",
     MMMMd => "MMMM d",
-    MMMMdd => "dd MMMM",
+    MMMMdd => "MMMM dd",
     MMMd => "MMM d",
     MMdd => "dd/MM",
     Md => "MM-dd",
@@ -40,33 +41,34 @@
     hm => "h:mm\N{U+202f}a",
     hms => "h:mm:ss\N{U+202f}a",
     hmsv => "h:mm:ss\N{U+202f}a v",
-    hmv => "h:mm\N{U+202f}a v",
+    hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
-    yM => "y-MM",
-    yMEd => "y-MM-dd, E",
+    yM => "M/y",
+    yMEd => "E, M/d/y",
     yMM => "MM/y",
-    yMMM => "y MMM",
-    yMMMEd => "y MMM d, E",
+    yMMM => "MMM y",
+    yMMMEd => "E, MMM d, y",
     yMMMM => "MMMM y",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
+    yMMMd => "MMM d, y",
+    yMd => "M/d/y",
     yQQQ => "QQQ y",
-    yQQQQ => "y QQQQ",
-    "yw-count-other" => "'week' w 'of' Y",
+    yQQQQ => "QQQQ y",
+    "yw-count-one" => "'torbee' w 'kan' Y",
+    "yw-count-other" => "'torbee' w 'kan' Y",
   },
   code => "om",
   date_format_full => "EEEE, MMMM d, y",
-  date_format_long => "dd MMMM y",
-  date_format_medium => "dd-MMM-y",
-  date_format_short => "dd/MM/yy",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  date_format_long => "MMMM d, y",
+  date_format_medium => "MMM d, y",
+  date_format_short => "M/d/yy",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "Wix",
-    "Qib",
+    "Kib",
     "Rob",
     "Kam",
     "Jim",
@@ -74,26 +76,26 @@
     "Dil",
   ],
   day_format_narrow => [
-    "M",
-    "T",
     "W",
-    "T",
-    "F",
-    "S",
+    "K",
+    "R",
+    "K",
+    "J",
     "S",
+    "D",
   ],
   day_format_wide => [
     "Wiixata",
-    "Qibxata",
+    "Kibxata",
     "Roobii",
-    "Kamiisa",
+    "Kamisa",
     "Jimaata",
     "Sanbata",
     "Dilbata",
   ],
   day_stand_alone_abbreviated => [
     "Wix",
-    "Qib",
+    "Kib",
     "Rob",
     "Kam",
     "Jim",
@@ -101,34 +103,34 @@
     "Dil",
   ],
   day_stand_alone_narrow => [
-    "M",
-    "T",
     "W",
-    "T",
-    "F",
-    "S",
+    "K",
+    "R",
+    "K",
+    "J",
     "S",
+    "D",
   ],
   day_stand_alone_wide => [
     "Wiixata",
-    "Qibxata",
+    "Kibxata",
     "Roobii",
-    "Kamiisa",
+    "Kamisa",
     "Jimaata",
     "Sanbata",
     "Dilbata",
   ],
   era_abbreviated => [
-    "BCE",
-    "CE",
+    "DhKD",
+    "BA",
   ],
   era_narrow => [
-    "BCE",
-    "CE",
+    "Dh",
+    "B",
   ],
   era_wide => [
-    "Dheengadda Jeesu",
-    "CE",
+    "Dhaloota Kiristoos Dura",
+    "Bara Araaraa",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -140,7 +142,7 @@
   month_format_abbreviated => [
     "Ama",
     "Gur",
-    "Bit",
+    "Bitootessa",
     "Elb",
     "Cam",
     "Wax",
@@ -148,41 +150,41 @@
     "Hag",
     "Ful",
     "Onk",
-    "Sad",
+    "Sadaasa",
     "Mud",
   ],
   month_format_narrow => [
-    "J",
+    "A",
+    "G",
+    "B",
+    "E",
+    "C",
+    "W",
+    "A",
+    "H",
     "F",
-    "M",
-    "A",
-    "M",
-    "J",
-    "J",
-    "A",
-    "S",
     "O",
-    "N",
-    "D",
+    "S",
+    "M",
   ],
   month_format_wide => [
     "Amajjii",
     "Guraandhala",
-    "Bitooteessa",
-    "Elba",
-    "Caamsa",
+    "Bitootessa",
+    "Eebila",
+    "Caamsaa",
     "Waxabajjii",
-    "Adooleessa",
+    "Adoolessa",
     "Hagayya",
-    "Fuulbana",
-    "Onkololeessa",
+    "Fulbaana",
+    "Onkoloolessa",
     "Sadaasa",
-    "Muddee",
+    "Mudde",
   ],
   month_stand_alone_abbreviated => [
     "Ama",
     "Gur",
-    "Bit",
+    "Bitootessa",
     "Elb",
     "Cam",
     "Wax",
@@ -190,36 +192,36 @@
     "Hag",
     "Ful",
     "Onk",
-    "Sad",
+    "Sadaasa",
     "Mud",
   ],
   month_stand_alone_narrow => [
-    "J",
+    "A",
+    "G",
+    "B",
+    "E",
+    "C",
+    "W",
+    "A",
+    "H",
     "F",
-    "M",
-    "A",
-    "M",
-    "J",
-    "J",
-    "A",
-    "S",
     "O",
-    "N",
-    "D",
+    "S",
+    "M",
   ],
   month_stand_alone_wide => [
     "Amajjii",
     "Guraandhala",
-    "Bitooteessa",
-    "Elba",
-    "Caamsa",
+    "Bitootessa",
+    "Eebila",
+    "Caamsaa",
     "Waxabajjii",
-    "Adooleessa",
+    "Adoolessa",
     "Hagayya",
-    "Fuulbana",
-    "Onkololeessa",
+    "Fulbaana",
+    "Onkoloolessa",
     "Sadaasa",
-    "Muddee",
+    "Mudde",
   ],
   name => "Oromo",
   native_language => "Oromoo",
@@ -228,10 +230,10 @@
   native_territory => undef,
   native_variant => undef,
   quarter_format_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "K1",
+    "K2",
+    "K3",
+    "K4",
   ],
   quarter_format_narrow => [
     1,
@@ -240,16 +242,16 @@
     4,
   ],
   quarter_format_wide => [
-    "Kurmaana 1",
-    "Kurmaana 2",
-    "Kurmaana 3",
-    "Kurmaana 4",
+    "Kurmaana 1ffaa",
+    "Kurmaana 2ffaa",
+    "Kurmaana 3ffaa",
+    "Kurmaana 4ffaa",
   ],
   quarter_stand_alone_abbreviated => [
-    "Q1",
-    "Q2",
-    "Q3",
-    "Q4",
+    "K1",
+    "K2",
+    "K3",
+    "K4",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -258,10 +260,10 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "Kurmaana 1",
-    "Kurmaana 2",
-    "Kurmaana 3",
-    "Kurmaana 4",
+    "Kurmaana 1ffaa",
+    "Kurmaana 2ffaa",
+    "Kurmaana 3ffaa",
+    "Kurmaana 4ffaa",
   ],
   script => undef,
   territory => undef,
@@ -270,5 +272,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
