@@ -46,8 +46,8 @@
     yMMM => "y MMM",
     yMMMEd => "y MMM d, E",
     yMMMM => "y MMMM",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
+    yMMMd => "d MMMM y",
+    yMd => "dd-MM-y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
     "yw-count-other" => "'week' w 'of' Y",
@@ -171,7 +171,7 @@
     "Kamena",
     "Nyakanga",
     "Kanama",
-    "Nzeli",
+    "Nzeri",
     "Ukwakira",
     "Ugushyingo",
     "Ukuboza",
@@ -213,14 +213,14 @@
     "Kamena",
     "Nyakanga",
     "Kanama",
-    "Nzeli",
+    "Nzeri",
     "Ukwakira",
     "Ugushyingo",
     "Ukuboza",
   ],
   name => "Kinyarwanda",
-  native_language => "Kinyarwanda",
-  native_name => "Kinyarwanda",
+  native_language => "Ikinyarwanda",
+  native_name => "Ikinyarwanda",
   native_script => undef,
   native_territory => undef,
   native_variant => undef,
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
