@@ -36,7 +36,7 @@
     MMMd => "MMM d",
     Md => "M/d",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss\N{U+202f}a v",
@@ -166,18 +166,18 @@
     "D",
   ],
   month_format_wide => [
-    "Bisha Koobaad",
-    "Bisha Labaad",
-    "Bisha Saddexaad",
-    "Bisha Afraad",
-    "Bisha Shanaad",
-    "Bisha Lixaad",
-    "Bisha Todobaad",
-    "Bisha Sideedaad",
-    "Bisha Sagaalaad",
-    "Bisha Tobnaad",
-    "Bisha Kow iyo Tobnaad",
-    "Bisha Laba iyo Tobnaad",
+    "Janaayo",
+    "Febraayo",
+    "Maarso",
+    "Abriil",
+    "Maayo",
+    "Juun",
+    "Luulyo",
+    "Agosto",
+    "Sebtembar",
+    "Oktoobar",
+    "Noofeembar",
+    "Diseembar",
   ],
   month_stand_alone_abbreviated => [
     "Jan",
@@ -212,9 +212,9 @@
     "Febraayo",
     "Maarso",
     "Abriil",
-    "May",
+    "Maayo",
     "Juun",
-    "Luuliyo",
+    "Luulyo",
     "Ogosto",
     "Sebteembar",
     "Oktoobar",
@@ -270,5 +270,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
