@@ -30,7 +30,7 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-one" => "'java' W 'e' MMMM",
+    "MMMMW-count-one" => "'java' W 'e' 'muajit' MMMM",
     "MMMMW-count-other" => "'java' W 'e' MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
@@ -271,5 +271,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
