@@ -8,8 +8,8 @@
     Bhm => "hh:mm B",
     Bhms => "hh:mm:ss B",
     E => "E",
-    EBhm => "E hh:mm B",
-    EBhms => "E hh:mm:ss B",
+    EBhm => "E h:mm B",
+    EBhms => "E, hh:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d.",
@@ -30,8 +30,8 @@
     MMM => "LLL",
     MMMEd => "E d. MMM",
     MMMMEd => "E, d. MMMM",
-    "MMMMW-count-few" => "W. 'sjedmica' 'u' MMMM",
-    "MMMMW-count-one" => "W. 'sjedmica' 'u' MMMM",
+    "MMMMW-count-few" => "MMMM: W. 'nedelja'",
+    "MMMMW-count-one" => "MMMM: W. 'nedelja'",
     "MMMMW-count-other" => "W. 'sjedmica' 'u' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
@@ -57,15 +57,15 @@
     yMd => "d. M. y.",
     yQQQ => "QQQ y.",
     yQQQQ => "QQQQ y.",
-    "yw-count-few" => "w. 'sjedmica' 'u' Y.",
-    "yw-count-one" => "w. 'sjedmica' 'u' Y.",
+    "yw-count-few" => "w. 'nedelja' 'u' Y.",
+    "yw-count-one" => "w. 'nedelja' 'u' Y.",
     "yw-count-other" => "w. 'sjedmica' 'u' Y.",
   },
   code => "sr-Latn-ME",
   date_format_full => "EEEE, d. MMMM y.",
   date_format_long => "d. MMMM y.",
   date_format_medium => "d. M. y.",
-  date_format_short => "d.M.yy.",
+  date_format_short => "d. M. y.",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
@@ -276,5 +276,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
