@@ -81,11 +81,11 @@
     "S",
   ],
   day_format_wide => [
-    "Mmantaha",
+    "Mantaha",
     "Labobedi",
-    "Laboraru",
+    "Laboraro",
     "Labone",
-    "Labohlane",
+    "Labohlano",
     "Moqebelo",
     "Sontaha",
   ],
@@ -108,11 +108,11 @@
     "S",
   ],
   day_stand_alone_wide => [
-    "Mmantaha",
+    "Mantaha",
     "Labobedi",
-    "Laboraru",
+    "Laboraro",
     "Labone",
-    "Labohlane",
+    "Labohlano",
     "Moqebelo",
     "Sontaha",
   ],
@@ -164,17 +164,17 @@
     12,
   ],
   month_format_wide => [
-    "Phesekgong",
+    "Pherekgong",
     "Hlakola",
     "Hlakubele",
-    "Mmese",
+    "Mmesa",
     "Motsheanong",
     "Phupjane",
     "Phupu",
-    "Phata",
-    "Leotshe",
+    "Phato",
+    "Lwetse",
     "Mphalane",
-    "Pundungwane",
+    "Pudungwana",
     "Tshitwe",
   ],
   month_stand_alone_abbreviated => [
@@ -206,24 +206,24 @@
     12,
   ],
   month_stand_alone_wide => [
-    "Phesekgong",
+    "Pherekgong",
     "Hlakola",
     "Hlakubele",
-    "Mmese",
+    "Mmesa",
     "Motsheanong",
     "Phupjane",
     "Phupu",
-    "Phata",
-    "Leotshe",
+    "Phato",
+    "Lwetse",
     "Mphalane",
-    "Pundungwane",
+    "Pudungwana",
     "Tshitwe",
   ],
   name => "Southern Sotho South Africa",
   native_language => "Sesotho",
-  native_name => "Sesotho",
+  native_name => "Sesotho Afrika Borwa",
   native_script => undef,
-  native_territory => undef,
+  native_territory => "Afrika Borwa",
   native_variant => undef,
   quarter_format_abbreviated => [
     "Q1",
@@ -268,5 +268,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
