@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "\N{U+0bae}\N{U+0bc1}\N{U+0bb1}\N{U+0bcd}\N{U+0baa}\N{U+0b95}\N{U+0bb2}\N{U+0bcd}",
-    "\N{U+0baa}\N{U+0bbf}\N{U+0bb1}\N{U+0bcd}\N{U+0baa}\N{U+0b95}\N{U+0bb2}\N{U+0bcd}",
+    "AM",
+    "PM",
   ],
   available_formats => {
     Bh => "B h",
@@ -13,13 +13,13 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d E",
-    Ehm => "E a h:mm",
-    Ehms => "E a h:mm:ss",
+    Ehm => "E h:mm a",
+    Ehms => "E h:mm:ss a",
     Gy => "G y",
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
-    GyMd => "GGGGG y-MM-dd",
+    GyMd => "d/M/y G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -32,15 +32,15 @@
     "MMMMW-count-one" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
     "MMMMW-count-other" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
     MMMMd => "d MMMM",
-    MMMd => "MMM d",
+    MMMd => "d MMM",
     MMdd => "dd-MM",
     Md => "d/M",
     d => "d",
-    h => "a h",
-    hm => "a h:mm",
-    hms => "a h:mm:ss",
-    hmsv => "a h:mm:ss v",
-    hmv => "a h:mm v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm a",
+    hms => "h:mm:ss a",
+    hmsv => "h:mm:ss a v",
+    hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
@@ -61,8 +61,8 @@
   date_format_long => "d MMMM, y",
   date_format_medium => "d MMM, y",
   date_format_short => "d/M/yy",
-  datetime_format_full => "{1} \N{U+0b85}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bc1} {0}",
-  datetime_format_long => "{1} \N{U+0b85}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bc1} {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -229,10 +229,10 @@
   native_territory => "\N{U+0b87}\N{U+0ba8}\N{U+0bcd}\N{U+0ba4}\N{U+0bbf}\N{U+0baf}\N{U+0bbe}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.1",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.2",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.3",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.4",
+    "\N{U+0b95}\N{U+0bbe}.1",
+    "\N{U+0b95}\N{U+0bbe}.2",
+    "\N{U+0b95}\N{U+0bbe}.3",
+    "\N{U+0b95}\N{U+0bbe}.4",
   ],
   quarter_format_narrow => [
     1,
@@ -241,16 +241,16 @@
     4,
   ],
   quarter_format_wide => [
-    "\N{U+0b92}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
+    "\N{U+0bae}\N{U+0bc1}\N{U+0ba4}\N{U+0bb2}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0b87}\N{U+0bb0}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0bae}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0ba8}\N{U+0bbe}\N{U+0ba9}\N{U+0bcd}\N{U+0b95}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.1",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.2",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.3",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.4",
+    "\N{U+0b95}\N{U+0bbe}.1",
+    "\N{U+0b95}\N{U+0bbe}.2",
+    "\N{U+0b95}\N{U+0bbe}.3",
+    "\N{U+0b95}\N{U+0bbe}.4",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -259,17 +259,17 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "\N{U+0b92}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
+    "\N{U+0bae}\N{U+0bc1}\N{U+0ba4}\N{U+0bb2}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0b87}\N{U+0bb0}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0bae}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0ba8}\N{U+0bbe}\N{U+0ba9}\N{U+0bcd}\N{U+0b95}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
   ],
   script => undef,
   territory => "India",
-  time_format_full => "a h:mm:ss zzzz",
-  time_format_long => "a h:mm:ss z",
-  time_format_medium => "a h:mm:ss",
-  time_format_short => "a h:mm",
+  time_format_full => "h:mm:ss a zzzz",
+  time_format_long => "h:mm:ss a z",
+  time_format_medium => "h:mm:ss a",
+  time_format_short => "h:mm a",
   variant => undef,
-  version => 41,
+  version => 46,
 }
