@@ -32,11 +32,11 @@
     "MMMMW-count-one" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
     "MMMMW-count-other" => "MMMM W -\N{U+0b86}\N{U+0bae}\N{U+0bcd} \N{U+0bb5}\N{U+0bbe}\N{U+0bb0}\N{U+0bae}\N{U+0bcd}",
     MMMMd => "d MMMM",
-    MMMd => "MMM d",
+    MMMd => "d MMM",
     MMdd => "dd-MM",
     Md => "d/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -229,10 +229,10 @@
   native_territory => "\N{U+0b9a}\N{U+0bbf}\N{U+0b99}\N{U+0bcd}\N{U+0b95}\N{U+0baa}\N{U+0bcd}\N{U+0baa}\N{U+0bc2}\N{U+0bb0}\N{U+0bcd}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.1",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.2",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.3",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.4",
+    "\N{U+0b95}\N{U+0bbe}.1",
+    "\N{U+0b95}\N{U+0bbe}.2",
+    "\N{U+0b95}\N{U+0bbe}.3",
+    "\N{U+0b95}\N{U+0bbe}.4",
   ],
   quarter_format_narrow => [
     1,
@@ -241,16 +241,16 @@
     4,
   ],
   quarter_format_wide => [
-    "\N{U+0b92}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
+    "\N{U+0bae}\N{U+0bc1}\N{U+0ba4}\N{U+0bb2}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0b87}\N{U+0bb0}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0bae}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0ba8}\N{U+0bbe}\N{U+0ba9}\N{U+0bcd}\N{U+0b95}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.1",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.2",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.3",
-    "\N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}.4",
+    "\N{U+0b95}\N{U+0bbe}.1",
+    "\N{U+0b95}\N{U+0bbe}.2",
+    "\N{U+0b95}\N{U+0bbe}.3",
+    "\N{U+0b95}\N{U+0bbe}.4",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -259,7 +259,7 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "\N{U+0b92}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
+    "\N{U+0bae}\N{U+0bc1}\N{U+0ba4}\N{U+0bb2}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0b87}\N{U+0bb0}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0bae}\N{U+0bc2}\N{U+0ba9}\N{U+0bcd}\N{U+0bb1}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
     "\N{U+0ba8}\N{U+0bbe}\N{U+0ba9}\N{U+0bcd}\N{U+0b95}\N{U+0bbe}\N{U+0bae}\N{U+0bcd} \N{U+0b95}\N{U+0bbe}\N{U+0bb2}\N{U+0bbe}\N{U+0ba3}\N{U+0bcd}\N{U+0b9f}\N{U+0bc1}",
@@ -271,5 +271,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
