@@ -46,8 +46,8 @@
     yMMM => "MMM y",
     yMMMEd => "E, d MMM, y",
     yMMMM => "MMMM y",
-    yMMMd => "d MMM, y",
-    yMd => "d/M/y",
+    yMMMd => "d MMM y",
+    yMd => "d.M.y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
     "yw-count-other" => "'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}\N{U+0438}' w, Y",
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
