@@ -12,14 +12,14 @@
     EBhms => "E h:mm:ss B",
     EHm => "E\N{U+1363} HH:mm",
     EHms => "E\N{U+1363} HH:mm:ss",
-    Ed => "E d",
+    Ed => "d E",
     Ehm => "E\N{U+1363} h:mm a",
     Ehms => "E\N{U+1363} h:mm:ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E\N{U+1363} d MMM y G",
-    GyMMMd => "d MMM y G",
-    GyMd => "d/M/y GGGGG",
+    GyMMMd => "MMM d, y G",
+    GyMd => "M/d/y G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -37,7 +37,7 @@
     MMdd => "d/M",
     Md => "d/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -48,10 +48,10 @@
     yMEd => "E\N{U+1363} d/M/y",
     yMM => "M/y",
     yMMM => "MMM y",
-    yMMMEd => "y MMM d, E",
+    yMMMEd => "E, MMM d, y",
     yMMMM => "MMMM y",
     yMMMd => "d MMM y",
-    yMd => "d/M/y",
+    yMd => "M/d/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
     "yw-count-one" => "\N{U+1230}\N{U+1219}\N{U+1295} w \N{U+1293}\N{U+12ed} Y",
@@ -59,9 +59,9 @@
   },
   code => "ti-ER",
   date_format_full => "EEEE\N{U+1363} d MMMM y",
-  date_format_long => "d MMMM y",
-  date_format_medium => "d MMM y",
-  date_format_short => "dd/MM/yy",
+  date_format_long => "MMMM d, y",
+  date_format_medium => "MMM d, y",
+  date_format_short => "M/d/yy",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
@@ -172,7 +172,7 @@
     "\N{U+1208}\N{U+12ab}\N{U+1272}\N{U+1275}",
     "\N{U+1218}\N{U+130b}\N{U+1262}\N{U+1275}",
     "\N{U+121a}\N{U+12eb}\N{U+12dd}\N{U+12eb}",
-    "\N{U+130d}\N{U+1295}\N{U+1266}\N{U+1275}",
+    "\N{U+1309}\N{U+1295}\N{U+1260}\N{U+1275}",
     "\N{U+1230}\N{U+1290}",
     "\N{U+1213}\N{U+121d}\N{U+1208}",
     "\N{U+1290}\N{U+1213}\N{U+1230}",
@@ -214,7 +214,7 @@
     "\N{U+1208}\N{U+12ab}\N{U+1272}\N{U+1275}",
     "\N{U+1218}\N{U+130b}\N{U+1262}\N{U+1275}",
     "\N{U+121a}\N{U+12eb}\N{U+12dd}\N{U+12eb}",
-    "\N{U+130d}\N{U+1295}\N{U+1266}\N{U+1275}",
+    "\N{U+1309}\N{U+1295}\N{U+1260}\N{U+1275}",
     "\N{U+1230}\N{U+1290}",
     "\N{U+1213}\N{U+121d}\N{U+1208}",
     "\N{U+1290}\N{U+1213}\N{U+1230}",
@@ -272,5 +272,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 45,
+  version => 46,
 }
