@@ -35,7 +35,7 @@
     MMMd => "d MMM",
     Md => "dd/MM",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss\N{U+202f}a (v)",
@@ -148,7 +148,7 @@
     "set",
     "oto",
     "nov",
-    "des",
+    "dez",
   ],
   month_format_narrow => [
     "J",
@@ -176,7 +176,7 @@
     "setenbre",
     "otobre",
     "novenbre",
-    "desenbre",
+    "dezenbre",
   ],
   month_stand_alone_abbreviated => [
     "jen",
@@ -190,7 +190,7 @@
     "set",
     "oto",
     "nov",
-    "des",
+    "dez",
   ],
   month_stand_alone_narrow => [
     "J",
@@ -218,7 +218,7 @@
     "setenbre",
     "otobre",
     "novenbre",
-    "desenbre",
+    "dezenbre",
   ],
   name => "Venetian",
   native_language => "veneto",
@@ -269,5 +269,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 45,
+  version => 46,
 }
