@@ -63,13 +63,13 @@
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
-    "Aj",
-    "\N{U+00cc}s\N{U+025b}\N{U+0301}g",
-    "\N{U+0186}j\N{U+0254}\N{U+0301}r",
-    "\N{U+0186}j\N{U+0254}\N{U+0301}b",
-    "\N{U+0190}t",
-    "\N{U+00c0}b\N{U+00e1}m",
-    "\N{U+00c0}\N{U+00ec}k",
+    "Aj\N{U+00e9}",
+    "\N{U+00cc}s\N{U+025b}\N{U+0301}gun",
+    "\N{U+0186}j\N{U+0254}\N{U+0301}r\N{U+00fa}",
+    "\N{U+0186}j\N{U+0254}\N{U+0301}b\N{U+0254}",
+    "\N{U+0190}t\N{U+00ec}",
+    "\N{U+00c0}b\N{U+00e1}m\N{U+025b}\N{U+0301}ta",
+    "\N{U+00c0}\N{U+00ec}k\N{U+00fa}",
   ],
   day_format_narrow => [
     "A",
@@ -90,13 +90,13 @@
     "\N{U+0186}j\N{U+0254}\N{U+0301} \N{U+00c0}\N{U+00ec}k\N{U+00fa}",
   ],
   day_stand_alone_abbreviated => [
-    "Aj",
-    "\N{U+00cc}s\N{U+025b}\N{U+0301}g",
-    "\N{U+0186}j\N{U+0254}\N{U+0301}r",
-    "\N{U+0186}j\N{U+0254}\N{U+0301}b",
-    "\N{U+0190}t",
-    "\N{U+00c0}b\N{U+00e1}m",
-    "\N{U+00c0}\N{U+00ec}k",
+    "Aj\N{U+00e9}",
+    "\N{U+00cc}s\N{U+025b}\N{U+0301}gun",
+    "\N{U+0186}j\N{U+0254}\N{U+0301}r\N{U+00fa}",
+    "\N{U+0186}j\N{U+0254}\N{U+0301}b\N{U+0254}",
+    "\N{U+0190}t\N{U+00ec}",
+    "\N{U+00c0}b\N{U+00e1}m\N{U+025b}\N{U+0301}ta",
+    "\N{U+00c0}\N{U+00ec}k\N{U+00fa}",
   ],
   day_stand_alone_narrow => [
     "A",
@@ -136,18 +136,18 @@
   glibc_time_format => "%H:%M:%S",
   language => "Yoruba",
   month_format_abbreviated => [
-    "Sh\N{U+025b}\N{U+0301}r",
-    "\N{U+00c8}r\N{U+00e8}l",
-    "\N{U+0190}r\N{U+025b}\N{U+0300}n",
-    "\N{U+00cc}gb",
-    "\N{U+0190}\N{U+0300}bi",
-    "\N{U+00d2}k\N{U+00fa}",
-    "Ag\N{U+025b}",
-    "\N{U+00d2}g\N{U+00fa}",
-    "Owe",
-    "\N{U+0186}\N{U+0300}w\N{U+00e0}",
-    "B\N{U+00e9}l",
-    "\N{U+0186}\N{U+0300}p\N{U+025b}",
+    "Osh\N{U+00f9} Sh\N{U+025b}\N{U+0301}r\N{U+025b}\N{U+0301}",
+    "Osh\N{U+00f9} \N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
+    "Osh\N{U+00f9} \N{U+0190}r\N{U+025b}\N{U+0300}n\N{U+00e0}",
+    "Osh\N{U+00f9} \N{U+00cc}gb\N{U+00e9}",
+    "Osh\N{U+00f9} \N{U+0190}\N{U+0300}bibi",
+    "Osh\N{U+00f9} \N{U+00d2}k\N{U+00fa}du",
+    "Osh\N{U+00f9} Ag\N{U+025b}m\N{U+0254}",
+    "Osh\N{U+00f9} \N{U+00d2}g\N{U+00fa}n",
+    "Osh\N{U+00f9} Owewe",
+    "Osh\N{U+00f9} \N{U+0186}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
+    "Osh\N{U+00f9} B\N{U+00e9}l\N{U+00fa}",
+    "Osh\N{U+00f9} \N{U+0186}\N{U+0300}p\N{U+025b}\N{U+0300}",
   ],
   month_format_narrow => [
     "S",
@@ -178,18 +178,18 @@
     "Osh\N{U+00f9} \N{U+0186}\N{U+0300}p\N{U+025b}\N{U+0300}",
   ],
   month_stand_alone_abbreviated => [
-    "Sh\N{U+025b}\N{U+0301}",
-    "\N{U+00c8}r",
-    "\N{U+0190}r",
-    "\N{U+00cc}g",
-    "\N{U+0190}\N{U+0300}b",
-    "\N{U+00d2}k",
-    "Ag",
-    "\N{U+00d2}g",
-    "Ow",
-    "\N{U+0186}\N{U+0300}w",
-    "B\N{U+00e9}",
-    "\N{U+0186}\N{U+0300}p",
+    "Osh\N{U+00f9} Sh\N{U+025b}\N{U+0301}r\N{U+025b}\N{U+0301}",
+    "Osh\N{U+00f9} \N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
+    "Osh\N{U+00f9} \N{U+0190}r\N{U+025b}\N{U+0300}n\N{U+00e0}",
+    "Osh\N{U+00f9} \N{U+00cc}gb\N{U+00e9}",
+    "Osh\N{U+00f9} \N{U+0190}\N{U+0300}bibi",
+    "Osh\N{U+00f9} \N{U+00d2}k\N{U+00fa}du",
+    "Osh\N{U+00f9} Ag\N{U+025b}m\N{U+0254}",
+    "Osh\N{U+00f9} \N{U+00d2}g\N{U+00fa}n",
+    "Osh\N{U+00f9} Owewe",
+    "Osh\N{U+00f9} \N{U+0186}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
+    "Osh\N{U+00f9} B\N{U+00e9}l\N{U+00fa}",
+    "Osh\N{U+00f9} \N{U+0186}\N{U+0300}p\N{U+025b}\N{U+0300}",
   ],
   month_stand_alone_narrow => [
     "S",
@@ -206,18 +206,18 @@
     "\N{U+0186}\N{U+0300}",
   ],
   month_stand_alone_wide => [
-    "Sh\N{U+025b}\N{U+0301}r\N{U+025b}\N{U+0301}",
-    "\N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
-    "\N{U+0190}r\N{U+025b}\N{U+0300}n\N{U+00e0}",
-    "\N{U+00cc}gb\N{U+00e9}",
-    "\N{U+0190}\N{U+0300}bibi",
-    "\N{U+00d2}k\N{U+00fa}du",
-    "Ag\N{U+025b}m\N{U+0254}",
-    "\N{U+00d2}g\N{U+00fa}n",
-    "Owewe",
-    "\N{U+0186}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
-    "B\N{U+00e9}l\N{U+00fa}",
-    "\N{U+0186}\N{U+0300}p\N{U+025b}\N{U+0300}",
+    "Osh\N{U+00f9} Sh\N{U+025b}\N{U+0301}r\N{U+025b}\N{U+0301}",
+    "Osh\N{U+00f9} \N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
+    "Osh\N{U+00f9} \N{U+0190}r\N{U+025b}\N{U+0300}n\N{U+00e0}",
+    "Osh\N{U+00f9} \N{U+00cc}gb\N{U+00e9}",
+    "Osh\N{U+00f9} \N{U+0190}\N{U+0300}bibi",
+    "Osh\N{U+00f9} \N{U+00d2}k\N{U+00fa}du",
+    "Osh\N{U+00f9} Ag\N{U+025b}m\N{U+0254}",
+    "Osh\N{U+00f9} \N{U+00d2}g\N{U+00fa}n",
+    "Osh\N{U+00f9} Owewe",
+    "Osh\N{U+00f9} \N{U+0186}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
+    "Osh\N{U+00f9} B\N{U+00e9}l\N{U+00fa}",
+    "Osh\N{U+00f9} \N{U+0186}\N{U+0300}p\N{U+025b}\N{U+0300}",
   ],
   name => "Yoruba Benin",
   native_language => "\N{U+00c8}d\N{U+00e8} Yor\N{U+00f9}b\N{U+00e1}",
@@ -250,10 +250,10 @@
     "\N{U+00cc}d\N{U+00e1}m\N{U+025b}\N{U+0301}rin K\N{U+025b}rin",
   ],
   quarter_stand_alone_narrow => [
-    "k\N{U+00ed}",
-    "Ke",
-    "K\N{U+025b}t",
-    "K\N{U+025b}r",
+    1,
+    2,
+    3,
+    4,
   ],
   quarter_stand_alone_wide => [
     "\N{U+00cc}d\N{U+00e1}m\N{U+025b}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
@@ -268,5 +268,5 @@
   time_format_medium => "H:m:s",
   time_format_short => "H:m",
   variant => undef,
-  version => 45,
+  version => 46,
 }
